==> 0.0.1.tar.gz: lib/src/orm/filter/filter_builder.dart <==
class ConditionLogic {
  static const String and = 'AND';
  static const String or = 'OR';
  static const String IN = 'IN';
}

class FilterBuilder {
  dynamic firstVar;
  dynamic secondVar;
  String condition;
  String? logic;
  List<FilterBuilder> conditionQueue = [];

  FilterBuilder(this.firstVar, this.condition, this.secondVar, [this.logic]) {
    conditionQueue.add(this);
  }
  String makeFilterQuery() {
    String query = '';
    for (var cond in conditionQueue) {
      if (cond.logic != null) {
        query += '  ' + cond.logic! + '  ';
      }
      query += '${cond.firstVar}  ${cond.condition}  ${cond.secondVar}';
    }
    return query;
  }

  FilterBuilder and(FilterBuilder cond) {
    cond.logic = ConditionLogic.and;
    conditionQueue.add(cond);

    return this;
  }

  FilterBuilder or(FilterBuilder cond) {
    cond.logic = ConditionLogic.or;
    conditionQueue.add(cond);
    return this;
  }
}

class Equals extends FilterBuilder {
  Equals(var firstVar, var secondVar, [String? logic])
      : super(firstVar, '=', secondVar, logic);
}

class In extends FilterBuilder {
  In(var firstVar, var secondVar, [String? logic])
      : super(firstVar, 'IN', secondVar, logic);
}

class NotIn extends FilterBuilder {
  NotIn(var firstVar, var secondVar, [String? logic])
      : super(firstVar, 'NOT IN', secondVar, logic);
}

class NotEquals extends FilterBuilder {
  NotEquals(var firstVar, var secondVar, [String? logic])
      : super(firstVar, '<>', secondVar, logic);
}

class LowerThan extends FilterBuilder {
  LowerThan(var firstVar, var secondVar, [String? logic])
      : super(firstVar, '<', secondVar, logic);
}

class BiggerThan extends FilterBuilder {
  BiggerThan(var firstVar, var secondVar, [String? logic])
      : super(firstVar, '>', secondVar, logic);
}

==> 0.0.2.tar.gz: lib/src/orm/filter/filter_builder.dart <==
import 'field.dart';
import 'sql_parser.dart';

class ConditionLogic {
  static const String and = 'AND';
  static const String or = 'OR';
  static const String iN = 'IN';
}

class FilterBuilder {
  Field firstVar;
  Field secondVar;
  String condition;
  String? logic;
  List<FilterBuilder> conditionQueue = [];

  FilterBuilder(this.firstVar, this.condition, this.secondVar, [this.logic]) {
    conditionQueue.add(this);
  }
  String makeFilterQuery() {
    String query = '';
    for (var cond in conditionQueue) {
      if (cond.logic != null) {
        query += '  ' + cond.logic! + '  ';
      }
      query +=
          '${SqlParser.toSql(cond.firstVar)}  ${cond.condition}  ${SqlParser.toSql(cond.secondVar)}';
    }

    return query;
  }

  FilterBuilder and(FilterBuilder cond) {
    cond.logic = ConditionLogic.and;
    conditionQueue.add(cond);

    return this;
  }

  FilterBuilder or(FilterBuilder cond) {
    cond.logic = ConditionLogic.or;
    conditionQueue.add(cond);
    return this;
  }
}

class Equals extends FilterBuilder {
  Equals(Field firstVar, Field secondVar, [String? logic])
      : super(firstVar, '=', secondVar, logic);
}

class In extends FilterBuilder {
  In(Field firstVar, Field secondVar, [String? logic])
      : super(firstVar, 'IN', secondVar, logic);
}

class NotIn extends FilterBuilder {
  NotIn(Field firstVar, Field secondVar, [String? logic])
      : super(firstVar, 'NOT IN', secondVar, logic);
}

class NotEquals extends FilterBuilder {
  NotEquals(Field firstVar, Field secondVar, [String? logic])
      : super(firstVar, '<>', secondVar, logic);
}

class LowerThan extends FilterBuilder {
  LowerThan(Field firstVar, Field secondVar, [String? logic])
      : super(firstVar, '<', secondVar, logic);
}

class BiggerThan extends FilterBuilder {
  BiggerThan(Field firstVar, Field secondVar, [String? logic])
      : super(firstVar, '>', secondVar, logic);
}
